@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Language::MuldisD; # package
-    use version; our $VERSION = qv('0.22.1');
+    use version; our $VERSION = qv('0.23.0');
     # Note that Perl code only exists at all in this file in order to help
     # the CPAN indexer handle the distribution properly.
 } # package Language::MuldisD
@@ -29,7 +29,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Language::MuldisD version 0.22.1.
+This document is Language::MuldisD version 0.23.0.
 
 =head1 PREFACE
 
@@ -40,7 +40,12 @@ L<Language::MuldisD::Basics>, L<Language::MuldisD::Core> (which has its own
 tree of parts to follow), L<Language::MuldisD::Dialect::PTMD_Tiny>,
 L<Language::MuldisD::Dialect::HDMD_Perl_Tiny>,
 L<Language::MuldisD::Hierarchical>, L<Language::MuldisD::Conventions>,
-L<Language::MuldisD::Ext::Temporal>, L<Language::MuldisD::Ext::Spatial>.
+L<Language::MuldisD::Ext::Ordered>, L<Language::MuldisD::Ext::Integer>,
+L<Language::MuldisD::Ext::Blob>, L<Language::MuldisD::Ext::Text>,
+L<Language::MuldisD::Ext::Nonscalar>, L<Language::MuldisD::Ext::Set>,
+L<Language::MuldisD::Ext::Sequence>, L<Language::MuldisD::Ext::Bag>,
+L<Language::MuldisD::Ext::Rational>, L<Language::MuldisD::Ext::Temporal>,
+L<Language::MuldisD::Ext::Spatial>.
 
 =head1 DESCRIPTION
 
@@ -53,9 +58,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:'cpan:DUNCAND':'0.22.1'>.  It is the official/original (not
+C<Muldis_D:'cpan:DUNCAND':'0.23.0'>.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<cpan:DUNCAND>), version C<0.22.1> (this number matches the
+Darren Duncan (C<cpan:DUNCAND>), version C<0.23.0> (this number matches the
 VERSION pod in this file).  This multi-part document is named and organized
 with the expectation that many dialects, extensions, and core versions of
 it will exist over time, some of those under the original author's control,
